@@ -1,7 +1,10 @@
 # flake8: noqa
 
 # import apis into api package
+from songtradr_api_client_python.api.api_keys_api import APIKeysApi
+from songtradr_api_client_python.api.admin_users_controller_api import AdminUsersControllerApi
 from songtradr_api_client_python.api.allowed_values_api import AllowedValuesApi
+from songtradr_api_client_python.api.internal_api_api import InternalApiApi
 from songtradr_api_client_python.api.party_api import PartyApi
 from songtradr_api_client_python.api.playlist_api import PlaylistApi
 from songtradr_api_client_python.api.recording_api import RecordingApi
